﻿
//======================================================
//
//		VIRTUALIZE INTERATIVIDADE DIGITAL
//
//		Classe para envio de mensagem de e-mail.
//		Versão AS 3.0.
//
//		- Funcionamento:
//			1) Instancie o um objeto. Ex: EmailSender("Nome do Remetente", 
//													  "E-mail do remetente",
//													  "Nome do destinatário",
//													  "E-mail do destinatário",
//													  "Assunto",
//													  "Mensagem....",
//													  "URL do script que realizará o envio (padrao é send_email.php)");
//
//
//			2) Utilize o método validate() para assegurar que todos os campos foram informados
//			   (Metodo util quando se utiliza como parâmetro do construtor referências à TextFields.
//					Ex: if (emailSender.validate()) { /* Envio do e-mail */ }
//				
//
//			3) Utiliza a função sendEmail para enviar o e-mail e definir quais funções devem ser chamadas
//			   a depender do resultado: sucesso ou falha.
//					Ex: emailSender.sendEmail( onSuccess, onFail );
//
//
//		- Script de envio:
//			O script de envio deve gerar um resposta, em formato XML para
//			o objeto, indicando o status do envio. O formato é apresentado a seguir:
//
//			<?xml version="1.0" encoding="UTF-8"?>
//			<data>
//				<result success="1"/>
//			</data>
//			
//			Em caso de falha, success="0".
//
//=======================================================
package vfl.as3.util
{
	import flash.events.Event;
	import flash.events.IOErrorEvent;
	import flash.events.SecurityErrorEvent;
	import flash.net.URLLoader;
	import flash.net.URLRequest;
	import flash.net.URLVariables;
	
	public class EmailSender
	{	
		public var senderName	: String;
		public var senderEmail	: String;	
	
		public var receiverName	: String;	
		public var receiverEmail: String;		
		
		public var subject		: String;
		
		public var message		: String;
		
		public var url			: String;
		
		public var onSuccess	: Function;
		public var onFail		: Function;	
		
		public function EmailSender(senderName_, 
									senderEmail_,
									receiverName_,
									receiverEmail_,
									subject_,
									message_,
									url_ = "send_email.php")
		{
			
			this.senderName 	= senderName_;
			this.senderEmail 	= senderEmail_;
			this.receiverName 	= receiverName_;
			this.receiverEmail	= receiverEmail_;
			this.subject		= subject_;
			this.message		= message_;
			
			this.url			= url_;
		}
		
		public function validate() : Boolean
		{
			return (this.senderName  	!= "" &&
					this.senderEmail 	!= "" &&
					this.receiverName	!= "" &&
					this.receiverEmail	!= "" &&
					this.subject		!= "" &&
					this.message 		!= "");
		}
		
		public function sendEmail(onSuccess_: Function, onFail_: Function)
		{
			this.onSuccess	 = onSuccess_;
			this.onFail		 = onFail_;
		
			// Objeto loader.
			var loader:URLLoader = new URLLoader();
			loader.addEventListener(Event.COMPLETE						, onLoadXMLFinish);
			loader.addEventListener(IOErrorEvent.IO_ERROR				, onLoadXMLFail);
			//loader.addEventListener(SecurityErrorEvent.SECURITY_ERROR	, onLoadXMLFail);
	
			// Objeto request.
			var request:URLRequest = new URLRequest(this.url);
			request.method = "POST";
	
			// Parâmetros passados para o script.		
			var variables:URLVariables = new URLVariables();
			variables.senderName 	= this.senderName;
			variables.senderEmail 	= this.senderEmail;
			variables.receiverName	= this.receiverName;
			variables.receiverEmail = this.receiverEmail;
			variables.subject		= this.subject;
			variables.message		= this.message;
			request.data = variables;
					
			loader.load(request);
		}
		
		public function onLoadXMLFinish(e: Event)
		{
			try 
			{
				var xmlData = new XML(e.target.data);
				trace(xmlData);
				var result	= int(xmlData.result.@success);
				
				trace("Result" + result);
				if (result == 1)	this.onSuccess();
				else				this.onFail();
			}
			catch (error:Error)
			{
				trace("[EmailSender.as] Erro ao interpretar XML: " + error);
				trace(xmlData);
				this.onFail();
			}
		}
		
		public function onLoadXMLFail(e: Event)
		{
			trace("[EmailSender.as] Erro ao carregar XML.");
			this.onFail();
		}
	}
}